@@ -5,7 +5,9 @@ use Continuity;
 use Guess;
 
 my $c = new Continuity(
-  appname => 'Guess'
+  appname => 'Guess',
+  print_html_header => 1,
+  print_form => 1,
 );
 
 $c->go();
