@@ -1,6 +1,12 @@
 
 package Continuity::Application;
 
+=head1 NAME
+
+Continuity::Application - Base class for Continuity applications
+
+=cut
+
 use strict;
 use warnings qw( all );
 use base 'Continuity::Module';
@@ -9,7 +15,6 @@ sub render
 {
   my $self = shift;
   my $c = $self->{continuity};
-  print $c->{s}->header() unless ($c->{printed_header});
   my $out = $self->{content};
   $self->{content} = '';
   $out =~ s/(<a\s.*?href=("|'))(.*?\?.*?)(\2.*?>)/$1$3&pid=$c->{newpid}$4/gm;
